==> pyglossary-4.8.0rc0.tar.gz: pyglossary-4.8.0rc0/pyglossary/iter_utils.py <==
# Copyright (c) 2019 Saeed Rasooli
# Copyright (c) 2012 Erik Rose

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

from typing import TYPE_CHECKING

if TYPE_CHECKING:
	from collections.abc import Iterable, Iterator
	from typing import Any

__all__ = ["unique_everseen"]


# from https://github.com/erikrose/more-itertools
def unique_everseen(iterable: "Iterable") -> "Iterator":
	"""List unique elements, preserving order. Remember all elements ever seen."""
	from itertools import filterfalse

	# unique_everseen('AAAABBBCCDAABBB') --> A B C D
	seen: "set[Any]" = set()
	seen_add = seen.add
	for element in filterfalse(seen.__contains__, iterable):
		seen_add(element)
		yield element

==> pyglossary-5.0.3.tar.gz: pyglossary-5.0.3/pyglossary/iter_utils.py <==
# Copyright (c) 2019 Saeed Rasooli
# Copyright (c) 2012 Erik Rose
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
	from collections.abc import Iterable, Iterator
	from typing import Any

__all__ = ["unique_everseen"]


# from https://github.com/erikrose/more-itertools
def unique_everseen(iterable: Iterable) -> Iterator:
	"""List unique elements, preserving order. Remember all elements ever seen."""
	from itertools import filterfalse

	# unique_everseen('AAAABBBCCDAABBB') --> A B C D
	seen: set[Any] = set()
	seen_add = seen.add
	for element in filterfalse(seen.__contains__, iterable):
		seen_add(element)
		yield element
